summaryrefslogtreecommitdiff
path: root/engine/yellow_intro.asm
diff options
context:
space:
mode:
authorYamaArashi <shadow962@live.com>2016-06-11 17:49:03 -0700
committerGitHub <noreply@github.com>2016-06-11 17:49:03 -0700
commitdb0ac16b6b4f257de338d1aaac561e681ca8723a (patch)
treed6888723f443557ce45c9a00d873caa5e7a8930e /engine/yellow_intro.asm
parent401d6e7f36e86aa246a2c0591195e1f0f01e879f (diff)
parentf5983c0f813d3d908b6016db3ed866e4ca9437dc (diff)
Merge pull request #14 from PikalaxALT/master
Yellow documentation
Diffstat (limited to 'engine/yellow_intro.asm')
-rwxr-xr-xengine/yellow_intro.asm18
1 files changed, 9 insertions, 9 deletions
diff --git a/engine/yellow_intro.asm b/engine/yellow_intro.asm
index 5aad4d33..3adb72b5 100755
--- a/engine/yellow_intro.asm
+++ b/engine/yellow_intro.asm
@@ -323,7 +323,7 @@ YellowIntroScene6:
call YellowIntro_BlankPalsDelay2AndDisableLCD
ld c, $5
call UpdateMusicCTimes
- ld a, $42
+ ld a, rSCY - $ff00
ld [hLCDCPointer], a
call YellowIntro_Copy8BitSineWave
ld hl, vBGMap0
@@ -359,8 +359,8 @@ YellowIntroScene7:
ld hl, hSCX
inc [hl]
inc [hl]
- ld hl, wYellowIntroSurfingPikaSineWaveBuffer
- ld de, wYellowIntroSurfingPikaSineWaveBuffer + 1
+ ld hl, wLYOverridesBuffer
+ ld de, wLYOverridesBuffer + 1
ld a, [hl]
push af
ld c, $ff
@@ -775,8 +775,8 @@ Func_f9e9a:
ret
YellowIntro_Copy8BitSineWave:
- ; Copy this sine wave into wYellowIntroSurfingPikaSineWaveBuffer 8 times (end just before wc900)
- ld de, wYellowIntroSurfingPikaSineWaveBuffer
+ ; Copy this sine wave into wLYOverridesBuffer 8 times (end just before wc900)
+ ld de, wLYOverridesBuffer
ld a, $8
.loop
push af
@@ -797,13 +797,13 @@ YellowIntro_Copy8BitSineWave:
.SineWaveEnd:
Request7TileTransferFromC810ToC710:
- ld a, wc810 % $100
+ ld a, $10
ld [H_VBCOPYSRC], a
- ld a, wc810 / $100
+ ld a, wLYOverridesBuffer / $100
ld [H_VBCOPYSRC + 1], a
- ld a, wc710 % $100
+ ld a, $10
ld [H_VBCOPYDEST], a
- ld a, wc710 / $100
+ ld a, wLYOverrides / $100
ld [H_VBCOPYDEST + 1], a
ld a, $7
ld [H_VBCOPYSIZE], a